@@ -49,6 +49,7 @@ use Class::XSAccessor (
             _src
             _src_filename
             _src_istmp
+            _temp_dir
             _tmp
             _tmpdir
             bindir
@@ -58,11 +59,10 @@ use Class::XSAccessor (
     }
 );
 
-use Getopt::Long 2.13;
+use Getopt::Long 2.13 ();
 use File::Spec ();
 use List::Util qw/ sum /;
-
-use IO::All qw/ io /;
+use Path::Tiny qw/ path tempdir /;
 use Term::ReadKey qw/ ReadMode ReadKey /;
 
 use TheWML::Config                        ();
@@ -119,12 +119,12 @@ sub _calc_epilogue_program
     }
     elsif ( $e =~ m|^linklint(.*)| )
     {
-        $e = "$libdir/exec/wml_aux_linklint$1";
+        $e = "linklint$1";
         $e .= " -nocache -one -summary" if ( $1 eq '' );
     }
     elsif ( $e =~ m|^weblint(.*)| )
     {
-        return "$libdir/exec/wml_aux_weblint$1";
+        return "weblint$1";
     }
     elsif ( $e =~ m|^tidy(.*)| )
     {
@@ -156,9 +156,8 @@ sub _handle_output
     #   to mtime of inputfile if inputfile was not STDIN
     if ( not $self->_src_istmp and $self->_opt_t )
     {
-        my $stat  = io->file( $self->_src );
         my $atime = time();
-        my $mtime = $stat->mtime;
+        my $mtime = path( $self->_src )->stat->mtime;
         foreach my $o ( @{ $self->_out_filenames } )
         {
             utime( $atime, $mtime + 1, $o );
@@ -471,15 +470,15 @@ sub _do_output
         {
             foreach my $o ( @{ $self->_out_filenames } )
             {
-                push @fh, io->file($o)->open('>');
+                push @fh, path($o)->openw;
             }
         }
         else
         {
             my $o = $self->_tmp->[3];
-            push @fh, io->file($o)->open('>');
+            push @fh, path($o)->openw;
         }
-        my $buf = io()->file( $self->_last )->all;
+        my $buf = path( $self->_last )->slurp_raw;
         foreach my $fp (@fh)
         {
             $fp->print($buf);
@@ -606,7 +605,7 @@ sub _process_shebang
     {
         return;
     }
-    my $tmp_fh  = io->file( $self->_src );
+    my $tmp_fh  = path( $self->_src )->openr;
     my $shebang = '';
 SHEBANG:
     while ( my $l = $tmp_fh->getline )
@@ -631,11 +630,12 @@ sub _calc_passes_options
     my ($self)    = @_;
     my $_pass_mgr = $self->_pass_mgr;
     my $libdir    = TheWML::Config::libdir();
+    my $datadir   = TheWML::Config::datadir();
     my ( $defipp, $defmp4h, $defeperl, $defgm4 ) = $self->_calc_default_opts();
 
     #   determine preloads
     my $preload = join '', map {
-        ( -f "$libdir/include/sys/bootp$_.wml" and /\A[34]\z/ )
+        ( -f "$datadir/include/sys/bootp$_.wml" and /\A[34]\z/ )
             ? " -s 'sys/bootp$_.wml'"
             : ''
     } @{ $self->_passes_idxs };
@@ -645,7 +645,7 @@ sub _calc_passes_options
 
     my $arr = [
         (
-                  "$defipp $verbose -S $libdir/include -n @{[$self->_src]} "
+                  "$defipp $verbose -S $datadir/include -n @{[$self->_src]} "
                 . ( join '', map { " -I $_" } @{ $self->_opt_I } )
                 . " $preload "
                 . (
@@ -703,9 +703,11 @@ sub _set_src
     if ( $self->_src eq '-' )
     {
         $self->_src_istmp(1);
-        $self->_src( $self->_tmpdir . "/wml.input.$$.tmp" );
+        $self->_src( $self->_temp_dir->child("wml.input.tmp") );
         unlink( $self->_src );
-        io->file( $self->_src )->print( io->stdin()->all );
+        path( $self->_src )->spew_raw(
+            do { local $/; <STDIN> }
+        );
     }
 
     if ( $self->_src_istmp and not -f $self->_src )
@@ -727,7 +729,7 @@ sub _output_and_cleanup
     #   ... and eventually send to stdout
     if ( $_pass_mgr->out_istmp )
     {
-        print io->file( $self->_tmp->[3] )->all;
+        print path( $self->_tmp->[3] )->slurp_raw;
     }
 
     $self->_unlink_tmp;
@@ -736,6 +738,7 @@ sub _output_and_cleanup
     {
         $_pass_mgr->_display_times;
     }
+    $self->_temp_dir('');
 
     return 0;
 }
@@ -746,7 +749,7 @@ sub _handle_out_tmp
 
     if ( not $self->_src_istmp )
     {
-        io->file( $self->_tmp->[0] )->print( io->file( $self->_src )->all );
+        path( $self->_tmp->[0] )->spew_raw( path( $self->_src )->slurp_raw );
     }
 
     if ( $self->_out eq '' )
@@ -842,6 +845,7 @@ sub run_with_ARGV
     $self->_opt_I( [] );
     $self->_opt_h(0);
     $self->_reset_opts;
+    $self->_temp_dir( tempdir() );
 
     my @temp_argv = @{ $self->_argv };
     $self->_process_options( \@temp_argv, [] );
@@ -891,13 +895,12 @@ sub run_with_ARGV
     #   Flag set if some output goes to stdout
     $_pass_mgr->out_istmp(0);
 
-    my $cwd = _my_cwd;
     $self->_opt_D_man->_populate_opt_D;
 
     #   Create temporary file names
     $self->_tmp(
         [
-            map { sprintf( "%s/wml.%s.tmp%d", $self->_tmpdir, $$, $_ + 1 ) }
+            map { $self->_temp_dir->child( sprintf( "wml.tmp%d", $_ + 1 ) ) }
                 0 .. 3
         ]
     );
