@@ -1,7 +1,5 @@
-##
-##  TEST.pl -- WML Test Suite utility functions
+##  wml_test/WmlTest.pm -- WML Test Suite utility functions
 ##  Copyright (c) 1997 Ralf S. Engelschall, All Rights Reserved.
-##
 
 package WmlTest;
 
@@ -9,17 +7,20 @@ use strict;
 use warnings;
 use autodie;
 
+use Carp::Always;
+
 use Test::More ();
 use File::Temp qw/ tempdir tempfile /;
-use IO::All qw/ io /;
+use Path::Tiny qw/ cwd path /;
 
 my @files_to_del;
 
-my $dir = tempdir( CLEANUP => 1 );
+my $orig_cwd = cwd->absolute;
+my $dir      = tempdir( CLEANUP => 1 );
 
 sub init
 {
-    return;
+    chdir $dir;
 }
 
 sub tmpfile
@@ -61,8 +62,8 @@ sub generic
     # $rc = system("cmp $tmpfile2 $tmpfile3");
 
     Test::More::is(
-        io()->file($tmpfile3)->all(),
-        io()->file($tmpfile2)->all(),
+        path($tmpfile3)->slurp_raw(),
+        path($tmpfile2)->slurp_raw(),
         "generic cmp"
     );
 }
@@ -78,6 +79,7 @@ sub cleanup
     {
         eval { unlink($fn); };
     }
+    chdir $orig_cwd;
 }
 
 1;
